//	CrystalFlightApp.swift
//
//	© 2025 by Jeff Weeks
//	See TermsOfUse.txt

import SwiftUI
import CoreMotion


let gMakeIcon: Bool = false

#if os(iOS)
//	Apple recommends using a single app-wide CMMotionManager
//	for best performance. I'm a little embarrassed to make it
//	a global variable, but this seems simpler than trying
//	to pass it through some object that's shared
//	at the Geometry Games level.
@MainActor let gMotionManager: CMMotionManager = {
	let theMotionManager = CMMotionManager()
	assert(
		theMotionManager.isDeviceMotionAvailable,
		"Device Motion should be available on all iOS devices (but if it's not, Crystal Flight would still work without it).")
	theMotionManager.startDeviceMotionUpdates()
	return theMotionManager
}()
#endif


@main
struct CrystalFlightApp: App {

	var body: some Scene {
#if os(iOS)
		WindowGroup {
			CrystalFlightContentView()
		}
#endif
#if os(macOS)
		WindowGroup {
			CrystalFlightContentView()
		}
		.defaultSize(
			width:  gMakeAppStoreScreenshots ? 1280.0 : 1024.0,
			height: gMakeAppStoreScreenshots ?  800.0 :  768.0)
#endif
	}
}
