//	CrystalFlightHelpView.swift
//
//	© 2025 by Jeff Weeks
//	See TermsOfUse.txt

import SwiftUI


struct CrystalFlightHelpView: View {

	var body: some View {

		VStack(alignment: .leading, spacing: 12) {

#if os(iOS)
			CrystalFlightHelpItem(
				what: "Steer-what",
				how: "Steer-how",
				altHow: "Steer-altHow")
#endif
#if os(macOS)
			CrystalFlightHelpItem(
				what: "Steer-what",
				how: "Steer-macOS",
				altHow: nil)
#endif

			CrystalFlightHelpItem(
				what: "Speed-what",
				how: "Speed-how",
				altHow: nil)

			CrystalFlightHelpItem(
				what: "Pause-what",
				how: "Pause-how",
				altHow: nil)

			CrystalFlightHelpItem(
				what: "Sidle-what",
				how: "Sidle-how",
				altHow: nil)

			CrystalFlightHelpItem(
				what: "Forward-what",
				how: "Forward-how",
				altHow: nil)

			CrystalFlightHelpItem(
				what: "Roll-what",
				how: "Roll-how",
				altHow: nil)
		}
		.padding(geometryGamesPanelPadding)
		.background(gSystemBackgroundColor)
		.cornerRadius(geometryGamesCornerRadius)
		.fixedSize()	//	Without this, the layout breaks on macOS, not sure why.
						//	On iOS it wasn't needed.

	}
}

struct CrystalFlightHelpItem: View {
	
	let what: LocalizedStringKey
	let how: LocalizedStringKey
	let altHow: LocalizedStringKey?
	
	var body: some View {

		VStack(alignment: .leading) {

			Text(what)
			.font(.title3)
			.italic()
			.foregroundColor(Color(
				.displayP3, red: 0.00, green: 0.50, blue: 0.25, opacity: 1.0))

			Text(how)
			.padding(EdgeInsets(
				top: 0.0, leading: 16.0, bottom: 0.0, trailing: 0.0))
			.font(.body)

			if let theAltHow = altHow {
	
				Text(theAltHow)
				.padding(EdgeInsets(
					top: 0.0, leading: 20.0, bottom: 0.0, trailing: 0.0))
				.font(.footnote)
				.foregroundColor(.gray)
			}
		}
		//	Counterintuitively, .lineLimit(nil) no longer works
		//	to allow multiline Text views, but .fixedSize(…) does.
		//	Note:  SwiftUI's .lineLimit(nil) is deterministic
		//	but inconsistent -- you might have three lines that
		//	get laid out correctly, but then when you add a fourth,
		//	the first line suddenly starts getting truncated.
		.fixedSize(horizontal: false, vertical: true)
	}
}


struct CrystalExplorerView: View {

	var body: some View {
	
		VStack(spacing: 8.0) {

			Text("Have access to a Vision Pro? Try")
			.font(.body)
			.multilineTextAlignment(.center)
		
			if let theCrystalExplorerURL
				= URL(string: "https://apps.apple.com/app/crystal-explorer/id6476159842")
			{

				Link(
					"Crystal Explorer",
					destination: theCrystalExplorerURL
				)
				.font(.title3)
				.modifier(blueForegroundOnMacOS())
				.multilineTextAlignment(.center)
	
			} else {	//	should never occur
				Text("https://apps.apple.com/app/crystal-explorer/id6476159842")
				.font(.title3)
			}

			Text("for a fully immersive 3D experience.")
			.font(.body)
			.multilineTextAlignment(.center)
		}
		.padding(geometryGamesPanelPadding)
		.background(gSystemBackgroundColor)
		.cornerRadius(geometryGamesCornerRadius)
	}
}


struct CrystalFlightHelpView_Previews: PreviewProvider {
	static var previews: some View {

		CrystalFlightHelpView()
			.environment(\.locale, .init(identifier: "pt"))
			.previewDevice(PreviewDevice(rawValue: "iPhone SE (2nd generation)"))
	}
}
